@@ -4,8 +4,8 @@
 /* count fields in vector of strings */
 
 void
-cnt_flds_str(char **strings, Sint *nstrings, char **sep, Sint
-	     *white_space, Sint *counts)
+R_cnt_flds_str(char **strings, Sint *nstrings, char **sep, Sint
+	       *white_space, Sint *counts)
 {
     Sint n = *nstrings, whitespace = *white_space;
     Sint i, nsep;
